@@ -1,7 +1,7 @@
 # ABSTRACT: Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 package PONAPI::Client;
 
-our $VERSION = '0.002005';
+our $VERSION = '0.002006';
 
 use Moose;
 
@@ -119,7 +119,9 @@ use constant OLD_HIJK => $Hijk::VERSION lt '0.16';
 
 sub _args {
     my $self = shift;
-    return ( @_, uri_base => $self->uri_base )
+    my %args = @_ == 1 ? %{ $_[0] } : @_;
+    $args{uri_base} = $self->uri_base;
+    return %args;
 }
 
 sub _send_ponapi_request {
@@ -189,7 +191,7 @@ PONAPI::Client - Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 
 =head1 VERSION
 
-version 0.002005
+version 0.002006
 
 =head1 SYNOPSIS
 
