@@ -18,8 +18,7 @@ has 'uri_base' => (
 );
 
 sub BUILDARGS {
-    my $class = shift;
-    my %args = @_ == 1 ? %{ $_[0] } : @_;
+    my ( $class, %args ) = @_;
     $args{uri_base} =~ s|/$||
         if exists $args{uri_base} and defined $args{uri_base};
     return \%args;
@@ -83,7 +82,7 @@ PONAPI::Client::Request - request class
 
 =head1 VERSION
 
-version 0.002005
+version 0.002006
 
 =head1 AUTHORS
 
